Many thanks to contributing to czbiohub/xicor!

Please fill in the appropriate checklist below (delete whatever is not relevant). These are the most common things requested on pull requests (PRs).

## PR checklist
 - [ ] This comment contains a description of changes (with reason)
 - [ ] If you've fixed a bug or added code that should be tested, add tests!
 - [ ] Ensure the test suite passes with [pytest](https://docs.pytest.org/en/latest/) . (command to run: `pytest` or `make coverage` if you want to see which lines don't have tests yet)
 - [ ] Make sure your code is linted and autoformatted using [black](https://github.com/psf/black) (`black . --check`).
 - [ ] Documentation in `usage.md` is updated
 - [ ] `README.md` is updated
